# Generated by Django 4.2.21 on 2025-12-21 21:14

import datetime
import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0092_userstatus_baseline_initialized'),
    ]

    operations = [
        migrations.CreateModel(
            name='EveItemPrice',
            fields=[
                ('eve_type_id', models.IntegerField(primary_key=True, serialize=False)),
                ('buy', models.FloatField()),
                ('sell', models.FloatField()),
                ('updated', models.DateTimeField(auto_now=True)),
            ],
            options={
                'verbose_name': 'Item Price',
                'verbose_name_plural': 'Item Prices',
            },
        ),
        migrations.DeleteModel(
            name='BigBrotherRedditMessage',
        ),
        migrations.DeleteModel(
            name='BigBrotherRedditSettings',
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='alliance_blacklist_url',
            field=models.URLField(blank=True, help_text='URL for the Alliance Blacklist', null=True, verbose_name='Alliance Blacklist URL'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='external_blacklist_url',
            field=models.URLField(blank=True, help_text='URL for the External/Coalition Blacklist', null=True, verbose_name='External Blacklist URL'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='market_transactions_excluded_systems',
            field=models.TextField(blank=True, help_text='System IDs separated by commas to be excluded from market transactions', verbose_name='Excluded Market Systems'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='market_transactions_fuzzwork_station_id',
            field=models.IntegerField(default=60003760, help_text='Default is 60003760 (Jita IV-4)', verbose_name='Fuzzwork Station ID'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='market_transactions_janice_api_key',
            field=models.TextField(blank=True, null=True, verbose_name='Janice API Key'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='market_transactions_price_instant',
            field=models.BooleanField(default=True, help_text='If enabled, uses immediate/instant prices. If disabled, uses average/percentile prices. Only works for Fuzzworks', verbose_name='Use Instant Prices'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='market_transactions_price_max_age',
            field=models.PositiveIntegerField(default=7, help_text='Maximum age of cached prices in days before refreshing from API.', verbose_name='Market Price Max Age (Days)'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='market_transactions_price_method',
            field=models.CharField(choices=[('Fuzzwork', 'Fuzzwork'), ('Janice', 'Janice')], default='Fuzzwork', max_length=20, verbose_name='Primary Price Method'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='market_transactions_show_major_hubs',
            field=models.BooleanField(default=False, help_text='Show Transactions that take place in the major market hubs (Jita, Amarr, Dodixie, Rens, Hek)', verbose_name='Show Major Hub Transactions'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='market_transactions_show_secondary_hubs',
            field=models.BooleanField(default=True, help_text='Show Transactions that take place in secondary market hubs (Oursulaert, Tash-Murkon Prime, Agil, Perimeter)', verbose_name='Show Secondary Hub Transactions'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='market_transactions_threshold_alert',
            field=models.BooleanField(default=False, help_text='Trigger alerts only when the purchased or sold price is more than the custom percentage threshold', verbose_name='Enable Market Price Threshold Alert'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='market_transactions_threshold_percent',
            field=models.FloatField(default=0, help_text='Custom percentage for market transaction alerts (e.g., 10.5 for 10.5%)', verbose_name='Market Price Threshold Percentage'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='show_market_transactions',
            field=models.BooleanField(default=False, help_text='Show transactions with a reference type of market_escrow and market_transaction', verbose_name='Show Market Transactions'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='update_backlog_notify',
            field=models.BooleanField(default=True, help_text='Whether to send an alert when a task backlog is detected.', verbose_name='Update Backlog Alert'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='update_backlog_threshold',
            field=models.PositiveIntegerField(default=10, help_text='Alert if more than this percentage of tasks from the previous run are still active.', verbose_name='Update Backlog Threshold (%)'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='update_cache_ttl_hours',
            field=models.IntegerField(default=24, help_text='How long certain check results are cached before being refreshed. Such as Clone States', verbose_name='Update Cache TTL (hours)'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='update_last_dispatch_count',
            field=models.IntegerField(default=0, editable=False, verbose_name='Last Dispatch Count'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='update_maintenance_window_end',
            field=models.TimeField(default=datetime.time(10, 0), help_text='End time for the maintenance window where caching is preferred.', verbose_name='Maintenance Window End (UTC)'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='update_maintenance_window_start',
            field=models.TimeField(default=datetime.time(6, 0), help_text='Start time for the maintenance window where updating cached data is preferred.', verbose_name='Maintenance Window Start (UTC)'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='update_stagger_seconds',
            field=models.IntegerField(default=3600, help_text='The total time window across which user updates are performed.', validators=[django.core.validators.MinValueValidator(3600)], verbose_name='Update Stagger Window (seconds)'),
        ),
        migrations.AddField(
            model_name='corpstatus',
            name='baseline_initialized',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='clone_state_always_recheck',
            field=models.BooleanField(default=False, help_text='If enabled, characters with a known skill proving their Alpha/Omega state will always be re-checked, bypassing the cache TTL, and potentially catching state changes far quicker. Disabling this can significantly improve performance.', verbose_name='Clone State: Always Re-check Proven Skills'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='contacts_source_corporations',
            field=models.ManyToManyField(blank=True, help_text='Corporations whose aa-contacts standings should be imported. Corporations with positive standing become members; negative standing become hostile; zero is ignored.', related_name='bb_contacts_source_configs_corp', to='eveonline.evecorporationinfo', verbose_name='aa-contacts source corporation'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='limit_to_main_corp',
            field=models.BooleanField(default=False, help_text='If enabled, compliance checks and dashboard visibility will be restricted to members of the primary corporation only.', verbose_name='Limit to Main Corporation'),
        ),
    ]



# Generated by Django 4.2.21 on 2025-12-23 16:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0093_eveitemprice_delete_bigbrotherredditmessage_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='corp_compliance_webhook',
            field=models.URLField(blank=True, help_text='Discord webhook for sending Corp compliance notifications', null=True, verbose_name='Corp Compliance Discord Webhook'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='user_compliance_webhook',
            field=models.URLField(blank=True, help_text='Discord webhook for sending User compliance notifications', null=True, verbose_name='User Compliance Discord Webhook'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='is_active',
            field=models.BooleanField(default=False, help_text='has the plugin been activated/deactivated?', verbose_name='Active?'),
        ),
    ]



# Generated by Django 4.2.23 on 2025-08-04 08:30

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django_celery_beat', '0019_alter_periodictasks_options'),
        ('aa_bb', '0023_optmessages1_optmessages2_optmessages3_optmessages4_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='dailyschedule',
            field=models.ForeignKey(blank=True, help_text='schedule for daily messages', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bigbrother_dailyschedule', to='django_celery_beat.crontabschedule'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='optschedule1',
            field=models.ForeignKey(blank=True, help_text='schedule for optional messages 1', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bigbrother_optschedule1', to='django_celery_beat.crontabschedule'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='optschedule2',
            field=models.ForeignKey(blank=True, help_text='schedule for optional messages 2', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bigbrother_optschedule2', to='django_celery_beat.crontabschedule'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='optschedule3',
            field=models.ForeignKey(blank=True, help_text='schedule for optional messages 3', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bigbrother_optschedule3', to='django_celery_beat.crontabschedule'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='optschedule4',
            field=models.ForeignKey(blank=True, help_text='schedule for optional messages 4', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bigbrother_optschedule4', to='django_celery_beat.crontabschedule'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='optschedule5',
            field=models.ForeignKey(blank=True, help_text='schedule for optional messages 5', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bigbrother_optschedule5', to='django_celery_beat.crontabschedule'),
        ),
    ]



# Generated by Django 4.2.23 on 2025-12-12 23:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_bb', '0088_bigbrotherconfig_cyno_notify'),
    ]

    operations = [
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='asset_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Asset Change notifications to discord'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='clone_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Clone State Change notifications to discord'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='contact_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Contact Change notifications to discord'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='contract_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Contract Change notifications to discord'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='mail_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Suspicious Mail notifications to discord'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='new_user_notify',
            field=models.BooleanField(default=False, help_text='Whether to send notifications of all previous user history when a user first gets audited, this can be VERY spammy on a first time load of the tool'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='sp_inject_notify',
            field=models.BooleanField(default=True, help_text='Whether to send SP Injection notifications to discord'),
        ),
        migrations.AddField(
            model_name='bigbrotherconfig',
            name='transaction_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Suspicious Transaction notifications to discord'),
        ),
        migrations.AlterField(
            model_name='bigbrotherconfig',
            name='cyno_notify',
            field=models.BooleanField(default=True, help_text='Whether to send Cyno Change notifications to discord'),
        ),
    ]



from django.test import TestCase
from django.utils import timezone
from datetime import timedelta
from unittest.mock import patch, MagicMock
from aa_bb.models import BigBrotherConfig, EveItemPrice
from aa_bb.app_settings import get_or_create_prices

class TestPriceTimer(TestCase):
    def setUp(self):
        self.config = BigBrotherConfig.get_solo()
        self.config.market_transactions_price_max_age = 10
        self.config.save()

    @patch('aa_bb.checks.sus_trans.requests.get')
    def test_price_timer_configurable(self, mock_get):
        # Create a price object that is 8 days old
        # With default 7 days it should refresh
        # With our config 10 days it should NOT refresh
        item_id = 1234
        old_date = timezone.now() - timedelta(days=8)
        price_obj = EveItemPrice.objects.create(
            eve_type_id=item_id,
            buy=100.0,
            sell=110.0
        )
        # Manually update the 'updated' field because it's auto_now=True
        EveItemPrice.objects.filter(eve_type_id=item_id).update(updated=old_date)

        # Reload from DB to be sure
        price_obj.refresh_from_db()

        # Call get_or_create_prices
        result = get_or_create_prices(item_id)

        # Verify it did NOT refresh (mock_get not called)
        self.assertFalse(mock_get.called)
        self.assertEqual(result.buy, 100.0)

        # Now change config to 5 days
        self.config.market_transactions_price_max_age = 5
        self.config.save()

        # Setup mock for refresh
        mock_response = MagicMock()
        mock_response.status_code = 200
        # Fuzzwork format
        mock_response.json.return_value = {
            "1234": {
                "buy": {"max": 200.0, "percentile": 190.0},
                "sell": {"min": 210.0, "percentile": 220.0}
            }
        }
        mock_get.return_value = mock_response
        self.config.market_transactions_price_method = 'Fuzzwork'
        self.config.save()

        # Call get_or_create_prices again
        result = get_or_create_prices(item_id)

        # Verify it DID refresh
        self.assertTrue(mock_get.called)
        self.assertEqual(result.buy, 200.0) # market_transactions_price_instant is True by default



from django.test import TestCase
from unittest.mock import patch, MagicMock
from aa_bb.checks.sus_contacts import get_user_hostile_notifications
from aa_bb.models import BigBrotherConfig

class TestSusContacts(TestCase):
    def setUp(self):
        self.cfg = BigBrotherConfig.get_solo()
        self.cfg.is_active = True
        self.cfg.save()

    @patch('aa_bb.checks.sus_contacts.get_user_contacts')
    @patch('aa_bb.checks.sus_contacts.get_hostile_state')
    def test_hostile_notification_with_positive_standing(self, mock_hostile_state, mock_get_user_contacts):
        # Setup: Positive standing with a hostile contact
        mock_get_user_contacts.return_value = {
            123: {
                'contact_type': 'character',
                'character': 'Hostile Guy',
                'standing': 5.0,
                'characters': {'Main Char'},
                'coid': 456,
                'corporation': 'Hostile Corp',
                'aid': 789,
                'alliance': 'Hostile Alliance',
            }
        }
        mock_hostile_state.side_effect = lambda cid, ctype: True

        notifications = get_user_hostile_notifications(1)

        self.assertEqual(len(notifications), 1)
        self.assertIn("is on hostile list", notifications[123])

    @patch('aa_bb.checks.sus_contacts.get_user_contacts')
    @patch('aa_bb.checks.sus_contacts.get_hostile_state')
    def test_no_hostile_notification_with_negative_standing(self, mock_hostile_state, mock_get_user_contacts):
        # Setup: Negative standing with a hostile contact
        mock_get_user_contacts.return_value = {
            123: {
                'contact_type': 'character',
                'character': 'Hostile Guy',
                'standing': -10.0,
                'characters': {'Main Char'},
                'coid': 456,
                'corporation': 'Hostile Corp',
                'aid': 789,
                'alliance': 'Hostile Alliance',
            }
        }
        mock_hostile_state.side_effect = lambda cid, ctype: True

        notifications = get_user_hostile_notifications(1)

        # Currently this will FAIL because it alerts regardless of standing
        self.assertEqual(len(notifications), 0, "Should not alert on negative standing with a hostile entity as it is redundant")

    @patch('aa_bb.checks.sus_contacts.get_user_contacts')
    @patch('aa_bb.checks.sus_contacts.get_hostile_state')
    def test_hostile_notification_with_neutral_standing(self, mock_hostile_state, mock_get_user_contacts):
        # Setup: Neutral standing (0) with a hostile contact
        mock_get_user_contacts.return_value = {
            123: {
                'contact_type': 'character',
                'character': 'Hostile Guy',
                'standing': 0.0,
                'characters': {'Main Char'},
                'coid': 456,
                'corporation': 'Hostile Corp',
                'aid': 789,
                'alliance': 'Hostile Alliance',
            }
        }
        mock_hostile_state.side_effect = lambda cid, ctype: True

        notifications = get_user_hostile_notifications(1)

        self.assertEqual(len(notifications), 1)
        self.assertIn("is on hostile list", notifications[123])



from django.test import TestCase
from django_celery_beat.models import PeriodicTask, IntervalSchedule, CrontabSchedule
from aa_bb.tasks_utils import setup_periodic_task, format_task_name
from aa_bb.models import BigBrotherConfig

class TestTaskSetup(TestCase):
    def setUp(self):
        self.schedule, _ = IntervalSchedule.objects.get_or_create(
            every=1,
            period=IntervalSchedule.HOURS,
        )

    def test_format_task_name(self):
        self.assertEqual(format_task_name("BB run regular updates"), "BB: Run Regular Updates")
        self.assertEqual(format_task_name("CB run regular updates"), "CB: Run Regular Updates")
        self.assertEqual(format_task_name("AA-BB: BB Run Regular Updates"), "BB: Run Regular Updates")
        self.assertEqual(format_task_name("tickets run regular updates"), "BB: Tickets Run Regular Updates")
        self.assertEqual(format_task_name("BB sync contacts from aa-contacts"), "BB: Sync Contacts From AA Contacts")

    def test_setup_periodic_task_creation(self):
        task_name = "BB run regular updates"
        setup_periodic_task(
            name=task_name,
            task_path="aa_bb.tasks.BB_run_regular_updates",
            schedule=self.schedule,
            enabled=True
        )

        expected_name = format_task_name(task_name)
        task = PeriodicTask.objects.get(name=expected_name)
        self.assertEqual(task.task, "aa_bb.tasks.BB_run_regular_updates")
        self.assertTrue(task.enabled)

    def test_setup_periodic_task_renaming(self):
        # Create a task with the old naming scheme
        old_name = "BB run regular updates"
        PeriodicTask.objects.create(
            name=old_name,
            task="aa_bb.tasks.BB_run_regular_updates",
            interval=self.schedule,
            enabled=True
        )

        # Now run setup_periodic_task which should rename it
        setup_periodic_task(
            name=old_name,
            task_path="aa_bb.tasks.BB_run_regular_updates",
            schedule=self.schedule,
            enabled=False
        )

        expected_name = format_task_name(old_name)

        # Old task should be gone (renamed)
        self.assertFalse(PeriodicTask.objects.filter(name=old_name).exists())

        # New task should exist with the standardized name
        task = PeriodicTask.objects.get(name=expected_name)
        self.assertFalse(task.enabled) # Should be disabled as requested in setup call

    def test_persistent_lifecycle(self):
        # Even if enabled=False, the task should be created
        task_name = "Some Optional Task"
        setup_periodic_task(
            name=task_name,
            task_path="aa_bb.tasks.some_task",
            schedule=self.schedule,
            enabled=False
        )

        expected_name = format_task_name(task_name)
        task = PeriodicTask.objects.get(name=expected_name)
        self.assertFalse(task.enabled)

        # Calling it again with enabled=True should update it
        setup_periodic_task(
            name=task_name,
            task_path="aa_bb.tasks.some_task",
            schedule=self.schedule,
            enabled=True
        )
        task.refresh_from_db()
        self.assertTrue(task.enabled)



# Generated by Django 4.2.23 on 2025-08-26 09:35

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('groupmanagement', '0019_adding_restricted_to_groups'),
        ('aa_bb', '0060_papsconfig_cap_group_papsconfig_cap_group_paps_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='papsconfig',
            name='cap_group',
        ),
        migrations.RemoveField(
            model_name='papsconfig',
            name='super_group',
        ),
        migrations.RemoveField(
            model_name='papsconfig',
            name='titan_group',
        ),
        migrations.AddField(
            model_name='papsconfig',
            name='cap_group',
            field=models.ForeignKey(blank=True, help_text='Select your cap group', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='cap_group', to='groupmanagement.authgroup'),
        ),
        migrations.AddField(
            model_name='papsconfig',
            name='super_group',
            field=models.ForeignKey(blank=True, help_text='Select your super group', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='super_group', to='groupmanagement.authgroup'),
        ),
        migrations.AddField(
            model_name='papsconfig',
            name='titan_group',
            field=models.ForeignKey(blank=True, help_text='Select your titan group', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='titan_group', to='groupmanagement.authgroup'),
        ),
    ]
